/*
 * Copyright © 2021 Fachhochschule für die Wirtschaft (FHDW) Hannover
 *
 * This file is part of ipspiel21-freizeit.
 *
 * Ipspiel21-freizeit is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software Foundation,
 * either version 3 of the License, or (at your option) any later version.
 *
 * Ipspiel21-freizeit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * You should have received a copy of the GNU General Public License along with ipspiel21-freizeit. If not, see
 * <http://www.gnu.org/licenses/>.
 */
package de.fhdw.gaming.ipspiel21.freizeit.strategy;

import java.util.Optional;

import de.fhdw.gaming.ipspiel21.freizeit.domain.FreizeitPlayer;
import de.fhdw.gaming.ipspiel21.freizeit.domain.FreizeitState;
import de.fhdw.gaming.ipspiel21.freizeit.domain.FreizeitStrategy;
import de.fhdw.gaming.ipspiel21.freizeit.moves.FreizeitMove;
import de.fhdw.gaming.ipspiel21.freizeit.moves.factory.FreizeitMoveFactory;

/**
 * Implements {@link FreizeitStrategy} by always saying "soccer".
 */
public final class FreizeitSaySoccerStrategy implements FreizeitStrategy {

    /**
     * The factory for creating Freizeit moves.
     */
    private final FreizeitMoveFactory moveFactory;

    /**
     * Creates an {@link FreizeitSaySoccerStrategy}.
     *
     * @param moveFactory The factory for creating Freizeit moves.
     */
    FreizeitSaySoccerStrategy(final FreizeitMoveFactory moveFactory) {
        this.moveFactory = moveFactory;
    }

    @Override
    public Optional<FreizeitMove> computeNextMove(final int gameId, final FreizeitPlayer player,
            final FreizeitState state) {
        return Optional.of(this.moveFactory.createSoccerMove());
    }

    @Override
    public String toString() {
        return FreizeitSaySoccerStrategy.class.getSimpleName();
    }
}
